@@ -318,8 +318,7 @@ class Collection(collection.Collection):
             return result
         return None
 
-    def find_and_modify(self, query=None, update=None, fields=None,
-                        upsert=False, remove=False, **kwargs):
+    def find_and_modify(self, query=None, update=None, fields=None, upsert=False, **kwargs):
         if query is None: query = {}
         before = self.find_one(query, sort=kwargs.get('sort'))
         upserted = False
@@ -330,21 +329,18 @@ class Collection(collection.Collection):
             else:
                 return None
         before = self.find_one(query, fields, sort=kwargs.get('sort'))
-        if remove:
-            self.remove({'_id': before['_id']})
-        elif not upserted:
+        if not upserted:
             self.update({'_id': before['_id']}, update)
         if kwargs.get('new', False) or upserted:
             return self.find_one(dict(_id=before['_id']), fields)
 
         return before
 
-    def insert(self, doc_or_docs, manipulate=True, safe=False, **kwargs):
+    def insert(self, doc_or_docs, safe=False, **kwargs):
         if not isinstance(doc_or_docs, list):
             doc_or_docs = [ doc_or_docs ]
         for doc in doc_or_docs:
-            if not manipulate:
-                doc = bcopy(doc)
+            doc = bcopy(doc)
             bson_safe(doc)
             _id = doc.get('_id', ())
             if _id == ():
@@ -539,18 +535,7 @@ class Cursor(object):
         # Le *sigh* -- this is the only place apparently where pymongo *does*
         # clone
         clone = self.clone()
-        if isinstance(key, slice):
-            _clone = clone
-            start, end = key.start, key.stop # step not supported
-            if start is None:
-                start = 0
-            _clone = _clone.skip(start)
-            if end is not None:
-                _clone = _clone.limit(end-start)
-            return _clone
-        elif isinstance(key, int):
-            return clone.skip(key).next()
-        raise TypeError('indicies must be integers, not %s' % type(key))
+        return clone.skip(key).next()
 
     def __iter__(self):
         return self
@@ -833,8 +818,6 @@ class MatchDoc(Match):
             return self, first
         if first not in self._doc:
             self._doc[first] = MatchDoc({})
-        if self._doc[first] is None:
-            return MatchDoc({}), None
         return self[first].traverse(*rest)
     def iteritems(self):
         return self._doc.iteritems()
@@ -855,8 +838,6 @@ class MatchDoc(Match):
     def setdefault(self, key, default):
         self._doc.setdefault(key, default)
         return self._orig.setdefault(key, default)
-    def keys(self):
-        return self._doc.keys()
 
 
 class MatchList(Match):
