@@ -2,9 +2,10 @@ from collections import defaultdict
 from unittest import TestCase, main
 
 import mock
+import bson
 import pymongo
 
-from ming.base import Object, Document, Field, Cursor
+from ming import Document, Field
 from ming import schema as S
 from ming.session import Session
 from ming.utils import ThreadLocalProxy
@@ -33,7 +34,7 @@ class TestSession(TestCase):
                 unique_indexes = [ ('cc'), ]
             _id=Field(S.ObjectId, if_missing=None)
             a=Field(S.Int, if_missing=None)
-            b=Field(S.Object, dict(a=S.Int(if_missing=None)))
+            b=Field(S.Object(dict(a=S.Int(if_missing=None))))
             cc=Field(dict(dd=int, ee=int))
         class TestDocNoSchema(Document):
             class __mongometa__:
@@ -59,7 +60,7 @@ class TestSession(TestCase):
         sess.remove(TestDoc, dict(a=5))
         sess.group(TestDoc, 'a')
         sess.update_partial(TestDoc, dict(a=5), dict(b=6), False)
-        
+
         impl.find_one.assert_called_with(dict(a=5))
         impl.find.assert_called_with(dict(a=5))
         impl.remove.assert_called_with(dict(a=5), safe=True)
@@ -84,7 +85,7 @@ class TestSession(TestCase):
         sess.save(doc, 'a')
         impl.update.assert_called_with(dict(_id=5), {'$set':dict(a=5)}, safe=True)
         doc = self.TestDocNoSchema({'_id':5, 'a':5})
-        impl.insert.return_value = pymongo.bson.ObjectId()
+        impl.insert.return_value = bson.ObjectId()
         sess.insert(doc)
         impl.insert.assert_called_with(dict(_id=5, a=5), safe=True)
         doc = self.TestDocNoSchema({'_id':5, 'a':5})
@@ -92,7 +93,7 @@ class TestSession(TestCase):
         impl.update.assert_called_with(dict(a=5), dict(_id=5, a=5), upsert=True, safe=True)
         sess.upsert(doc, '_id')
         impl.update.assert_called_with(dict(_id=5), dict(_id=5, a=5), upsert=True, safe=True)
-        
+
         sess.find_by(self.TestDoc, a=5)
         sess.count(self.TestDoc)
         sess.ensure_index(self.TestDoc, 'a')
@@ -100,12 +101,18 @@ class TestSession(TestCase):
         impl.count.assert_called_with()
         impl.ensure_index.assert_called_with([ ('a', pymongo.ASCENDING) ])
         impl.ensure_index.reset_mock()
-        
+
         sess.ensure_indexes(self.TestDoc)
-        self.assertEqual(impl.ensure_index.call_args_list, [
-            (([('b', pymongo.ASCENDING), ('c', pymongo.ASCENDING) ],), {}),
-            (([('cc', pymongo.ASCENDING) ],), {'unique':True}),
-        ])
+        self.assertEqual(
+            impl.ensure_index.call_args_list, [
+                (
+                    ([ ('b', pymongo.ASCENDING), ('c', pymongo.ASCENDING) ],),
+                    {'unique':False, 'sparse':False, 'background': True} ),
+
+                (
+                    ([ ('cc', pymongo.ASCENDING) ],),
+                    {'unique':True, 'sparse':False, 'background':True} ),
+                ])
 
         doc = self.TestDocNoSchema(dict(_id=1, a=5))
         sess.set(doc, dict(b=5))
@@ -125,13 +132,21 @@ class TestSession(TestCase):
                                        {'$set': dict(b=60)},
                                        safe=True)
         self.assertRaises(ValueError, sess.increase_field, doc, b=None)
-        
+
         sess.index_information(self.TestDoc)
         impl.index_information.assert_called_with()
-        
+
         sess.drop_indexes(self.TestDoc)
         impl.drop_indexes.assert_called_with()
 
+        self.assertRaises(ValueError, sess.remove, doc, foobar='baz')
+
+    def test_find_kwargs(self):
+        sess = self.session
+        TestDoc = self.TestDoc
+        self.assertRaises(ValueError, sess.find, TestDoc, a=5)
+
+
 class TestThreadLocalSession(TestSession):
 
     def setUp(self):
@@ -145,7 +160,7 @@ class TestThreadLocalSession(TestSession):
                 unique_indexes = [ ('cc'), ]
             _id=Field(S.ObjectId, if_missing=None)
             a=Field(S.Int, if_missing=None)
-            b=Field(S.Object, dict(a=S.Int(if_missing=None)))
+            b=Field(S.Object(dict(a=S.Int(if_missing=None))))
             cc=Field(dict(dd=int, ee=int))
         class TestDocNoSchema(Document):
             class __mongometa__:
@@ -159,8 +174,7 @@ class TestThreadLocalSession(TestSession):
 
     def test_basic_tl_session(self):
         pass
-        
-        
+
+
 if __name__ == '__main__':
     main()
-
